@@ -235,6 +235,27 @@ class TestTraversal(TestCase):
            </html>
            """
 
+    html2 = """
+            <html>
+             <body>
+               <dl>
+                 <dt id="term-1">term 1</dt>
+                 <dd>definition 1-a</dd>
+                 <dd>definition 1-b</dd>
+                 <dd>definition 1-c</dd>
+                 <dd>definition 1-d</dd>
+                 <dt id="term-2">term 2</dt>
+                 <dd>definition 2-a</dd>
+                 <dd class="strange">definition 2-b</dd>
+                 <dd>definition 2-c</dd>
+                 <dt id="term-3">term 3</dt>
+                 <dd>definition 3-a</dd>
+                 <dd>definition 3-b</dd>
+               </dl>
+             </body>
+            </html>
+            """
+
     def test_filter(self):
         assert len(self.klass('div', self.html).filter('.node3')) == 1
         assert len(self.klass('div', self.html).filter('#node2')) == 1
@@ -278,6 +299,32 @@ class TestTraversal(TestCase):
                           self.html).closest('.node3').attr('id') == 'node2'
         assert self.klass('.node3', self.html).closest('form') == []
 
+    def test_next_all(self):
+        d = pq(self.html2)
+
+        # without filter
+        self.assertEqual(
+            len(d('#term-2').next_all()), 6)
+        # with filter
+        self.assertEqual(
+            len(d('#term-2').next_all('dd')), 5)
+        # when empty
+        self.assertEqual(
+            d('#NOTHING').next_all(), [])
+
+    def test_next_until(self):
+        d = pq(self.html2)
+
+        # without filter
+        self.assertEqual(
+            len(d('#term-2').next_until('dt')), 3)
+        # with filter
+        self.assertEqual(
+            len(d('#term-2').next_until('dt', ':not(.strange)')), 2)
+        # when empty
+        self.assertEqual(
+            d('#NOTHING').next_until('*'), [])
+
 
 class TestOpener(TestCase):
 
@@ -321,13 +368,17 @@ class TestCallback(TestCase):
 
     def test_S_this_inside_callback(self):
         S = pq(self.html)
-        self.assertEqual(S('li').map(lambda i, el: S(this).html()),  # NOQA
-                                     ['Coffee', 'Tea', 'Milk'])
+        self.assertEqual(S('li').map(
+            lambda i, el: S(this).html()),  # NOQA
+            ['Coffee', 'Tea', 'Milk']
+        )
 
     def test_parameterless_callback(self):
         S = pq(self.html)
-        self.assertEqual(S('li').map(lambda: S(this).html()),  # NOQA
-                                     ['Coffee', 'Tea', 'Milk'])
+        self.assertEqual(S('li').map(
+            lambda: S(this).html()),  # NOQA
+            ['Coffee', 'Tea', 'Milk']
+        )
 
 
 class TestHook(TestCase):
@@ -440,9 +491,9 @@ Bacon</textarea>
         d = pq(self.html)
         d('img').remove()
         val = d('a:first').html()
-        assert val == 'Test My link text', repr(val)
+        assert val == 'TestMy link text', repr(val)
         val = d('a:last').html()
-        assert val == ' My link text 2', repr(val)
+        assert val == 'My link text 2', repr(val)
 
     def test_class(self):
         d = pq('<div></div>')
@@ -483,9 +534,10 @@ Bacon</textarea>
         self.assertEqual(d('#textarea-multi').val(), multi_expected)
         self.assertEqual(d('#textarea-multi').text(), multi_expected)
         multi_new = '''Bacon\n<b>Eggs</b>\nSpam'''
+        multi_new_expected = '''Bacon\n&lt;b&gt;Eggs&lt;/b&gt;\nSpam'''
         d('#textarea-multi').val(multi_new)
-        self.assertEqual(d('#textarea-multi').val(), multi_new)
-        self.assertEqual(d('#textarea-multi').text(), multi_new)
+        self.assertEqual(d('#textarea-multi').val(), multi_new_expected)
+        self.assertEqual(d('#textarea-multi').text(), multi_new_expected)
 
     def test_val_for_select(self):
         d = pq(self.html4)
@@ -571,6 +623,13 @@ Bacon</textarea>
         self.assertEqual(new_html, expected)
         self.assertIn(replacement, new_html)
 
+    def test_html_escape(self):
+        inner_html = 'encoded &lt;script&gt; tag with "quotes".' \
+                     '<span>nested &lt;tag&gt;</span>'
+        html = '<div>' + inner_html + '</div>'
+        d = pq(html)
+        self.assertEqual(d.html(), inner_html)
+
 
 class TestAjax(TestCase):
 
@@ -843,14 +902,14 @@ class TestWebScrapping(TestCase):
         self.application_url = self.s.application_url.rstrip('/')
 
     def test_get(self):
-        d = pq(self.application_url, {'q': 'foo'},
+        d = pq(url=self.application_url, data={'q': 'foo'},
                method='get')
         print(d)
         self.assertIn('REQUEST_METHOD: GET', d('p').text())
         self.assertIn('q=foo', d('p').text())
 
     def test_post(self):
-        d = pq(self.application_url, {'q': 'foo'},
+        d = pq(url=self.application_url, data={'q': 'foo'},
                method='post')
         self.assertIn('REQUEST_METHOD: POST', d('p').text())
         self.assertIn('q=foo', d('p').text())
@@ -860,7 +919,7 @@ class TestWebScrapping(TestCase):
             import requests
             session = requests.Session()
             session.headers.update({'X-FOO': 'bar'})
-            d = pq(self.application_url, {'q': 'foo'},
+            d = pq(url=self.application_url, data={'q': 'foo'},
                    method='get', session=session)
             self.assertIn('HTTP_X_FOO: bar', d('p').text())
         else:
@@ -873,7 +932,7 @@ class TestWebScrapping(TestCase):
 class TestWebScrappingEncoding(TestCase):
 
     def test_get(self):
-        d = pq(u'http://ru.wikipedia.org/wiki/Заглавная_страница',
+        d = pq(url=u'http://ru.wikipedia.org/wiki/Заглавная_страница',
                method='get')
         print(d)
         self.assertEqual(d('#pt-login').text(), u'Войти')
@@ -891,9 +950,9 @@ class TestWebScrappingTimeouts(TestCase):
         self.application_url = self.s.application_url.rstrip('/')
 
     def test_get(self):
-        pq(self.application_url)
+        pq(url=self.application_url)
         with self.assertRaises(Exception):
-            pq(self.application_url, timeout=1)
+            pq(url=self.application_url, timeout=1)
 
     def tearDown(self):
         self.s.shutdown()
